@@ -674,7 +674,10 @@ foreach my $info (@list) {
             foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
                 my $blit_time = time;
                 $F->blit_write($image->[$frame]);
-                sleep (($image->[$frame]->{'tags'}->{'gif_delay'} * .01) - (time - $blit_time));
+                my $delay = (($image->[$frame]->{'tags'}->{'gif_delay'} * (.01 - (time - $blit_time))));
+                if ($delay > 0) {
+                    sleep $delay;
+                }
             }
         }
     }
